@@ -2,9 +2,14 @@
 # website:	http://www.pyshine.com
 
 # set the version number
-__version__= "0.0.6"
+__version__= "0.0.8"
 
 # import the necessary packages
 from .convenience import putBText
 from .convenience import audioCapture
 from .convenience import showPlot
+from .convenience import RPSNET
+from .convenience import StreamProps
+from .convenience import Streamer
+from .convenience import StreamOut
+
